@@ -28,11 +28,10 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <knotifydialog.h>
 #include <kiconloader.h>
-#include <kaboutkde.h>
 #include <kaction.h>
-#include <kaboutapplication.h>
-#include <kbugreport.h>
+#include <khelpmenu.h>
 #include <kglobalaccel.h>
 #include <kkeydialog.h>
 #include <kmessagebox.h>
@@ -45,25 +44,29 @@ RSIDock::RSIDock( QWidget *parent, const char *name )
 
 {
 
-    contextMenu()->insertItem(SmallIcon("configure"),
-                            i18n("Configure RSIBreak..."), this,
-                            SLOT(slotConfigure()));
+    m_help = new KHelpMenu( this, KGlobal::instance()->aboutData() );
+
+    contextMenu()->insertItem(SmallIcon("about_kde"), m_help->menu()->text(KHelpMenu::menuAboutKDE),
+                              m_help, SLOT(aboutKDE()));
+    contextMenu()->insertItem(SmallIcon("info"),  m_help->menu()->text(KHelpMenu::menuAboutApp),
+                              m_help, SLOT(aboutApplication()));
+    contextMenu()->insertItem(SmallIcon("contents"),  m_help->menu()->text(KHelpMenu::menuHelpContents),
+                              m_help, SLOT(appHelpActivated()));
+    contextMenu()->insertSeparator();
+    contextMenu()->insertItem(m_help->menu()->text(KHelpMenu::menuReportBug),
+                              m_help, SLOT(reportBug()));
+    contextMenu()->insertSeparator();
     m_suspendItem = contextMenu()->insertItem(SmallIcon("player_pause"),
-                            i18n("Suspend RSIBreak"), this,
-                            SLOT(slotSuspend()));
-    contextMenu()->insertItem(SmallIcon("gear"),
-                            i18n("Usage Statistics"), this,
-                            SLOT( slotShowStatistics() ) );
-    contextMenu()->insertSeparator();
-    contextMenu()->insertItem(i18n("Report Bug..."), this,
-                            SLOT(slotReportBug()));
-    contextMenu()->insertSeparator();
-    contextMenu()->insertItem(SmallIcon("about_kde"),
-                            i18n("About KDE"), this,
-                            SLOT(slotAboutKDE()));
-    contextMenu()->insertItem(SmallIcon("info"),
-                            i18n("About RSIBreak"), this,
-                            SLOT(slotAboutRSIBreak()));
+                              i18n("&Suspend RSIBreak"), this,
+                              SLOT(slotSuspend()));
+    contextMenu()->insertItem(i18n("&Usage Statistics"),
+                              this, SLOT( slotShowStatistics() ) );
+    contextMenu()->insertItem(SmallIcon("knotify"),
+                              i18n("Configure &Notifications..."),
+                              this, SLOT(slotConfigureNotifications()));
+    contextMenu()->insertItem(SmallIcon("configure"),
+                              i18n("&Configure RSIBreak..."),
+                              this, SLOT(slotConfigure()));
 
     m_accel = new KGlobalAccel(this);
     m_accel->insert("breakRequest", i18n("This is where the user can request a "
@@ -71,6 +74,11 @@ RSIDock::RSIDock( QWidget *parent, const char *name )
                     i18n("This way you can have a break now"),
                     KKey::QtWIN+SHIFT+Key_B, KKey::QtWIN+CTRL+Key_B,
                     this, SLOT( slotBreakRequest() ));
+    m_accel->insert("debugRequest", "This is where the user can request a "
+            "continues dump of timings",
+            i18n("This way you can have a break now"),
+            KKey::QtWIN+SHIFT+Key_F12, KKey::QtWIN+CTRL+Key_F12,
+            this, SLOT( slotDebugRequest() ));
     m_accel->updateConnections();
 
     m_tooltiptimer = new QTimer( this );
@@ -83,6 +91,12 @@ RSIDock::~RSIDock()
     m_statsWidget = 0;
 }
 
+
+void RSIDock::slotConfigureNotifications()
+{
+    KNotifyDialog::configure( this );
+}
+
 void RSIDock::slotConfigure()
 {
     Setup setup(this);
@@ -94,29 +108,16 @@ void RSIDock::slotConfigure()
       emit dialogLeft();
 }
 
-void RSIDock::slotAboutKDE()
-{
-    KAboutKDE about;
-    about.exec();
-}
-
-void RSIDock::slotAboutRSIBreak()
-{
-    KAboutApplication a( KGlobal::instance()->aboutData(), this );
-    a.exec();
-}
-
-void RSIDock::slotReportBug()
-{
-    KBugReport bug;
-    bug.exec();
-}
-
 void RSIDock::slotBreakRequest()
 {
     emit breakRequest();
 }
 
+void RSIDock::slotDebugRequest()
+{
+    emit debugRequest();
+}
+
 void RSIDock::slotSuspend()
 {
     if( m_suspended )
@@ -125,7 +126,7 @@ void RSIDock::slotSuspend()
 
         setPixmap( KSystemTray::loadIcon( "rsibreak0" ) );
         contextMenu()->changeItem( m_suspendItem, SmallIcon( "player_pause" ),
-                                   i18n("Suspend RSIBreak") );
+                                   i18n("&Suspend RSIBreak") );
     }
     else
     {
@@ -133,7 +134,7 @@ void RSIDock::slotSuspend()
 
         setPixmap( KSystemTray::loadIcon( "rsibreakx" ) );
         contextMenu()->changeItem( m_suspendItem, SmallIcon( "player_play" ),
-                                   i18n( "Resume RSIBreak" ) );
+                                   i18n( "&Resume RSIBreak" ) );
     }
 
     m_suspended = !m_suspended;
@@ -206,12 +207,20 @@ void RSIDock::slotShowStatistics()
       m_statsDialog->setMainWidget( m_statsWidget );
     }
 
-    m_statsDialog->show();
+    if ( m_statsDialog->isVisible() &&
+         KWin::windowInfo( m_statsDialog->winId() ).desktop() == KWin::currentDesktop() )
+    {
+      m_statsDialog->hide();
+    }
+    else
+    {
+      m_statsDialog->show();
 
-    if (!m_statsDialog->isActiveWindow())
-	    KWin::forceActiveWindow(m_statsDialog->winId());
+      if (!m_statsDialog->isActiveWindow())
+        KWin::forceActiveWindow(m_statsDialog->winId());
 
-    m_statsDialog->raise();
+      m_statsDialog->raise();
+    }
 }
 
 void RSIDock::slotResetStats()
