@@ -21,8 +21,10 @@
 #include <qpushbutton.h>
 #include <qtimer.h>
 #include <qvbox.h>
+#include <qtooltip.h>
 
 #include <kdebug.h>
+#include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kprogress.h>
@@ -48,6 +50,10 @@ RSIRelaxPopup::RSIRelaxPopup( QWidget *parent, const char *name )
 
     m_lockbutton = new QPushButton( SmallIcon( "lock" ), QString::null, hbox );
     connect( m_lockbutton, SIGNAL( clicked() ), SIGNAL( lock() ) );
+    QToolTip::add( m_lockbutton, i18n( "Lock the session") );
+    m_skipbutton = new QPushButton( SmallIcon( "cancel" ), QString::null, hbox );
+    connect( m_skipbutton, SIGNAL( clicked() ), SIGNAL ( skip() ) );
+    QToolTip::add( m_skipbutton, i18n( "Skip this break") );
 
     setTimeout( 0 ); // no auto close
     setView( vbox );
@@ -114,8 +120,8 @@ void RSIRelaxPopup::flash()
     if( m_useFlash )
     {
       QTimer::singleShot( 500, this, SLOT( unflash() ) );
-      setPaletteForegroundColor( QColor( 255, 255, 255 ) );
-      setPaletteBackgroundColor( QColor( 0, 0, 120 ) );
+      setPaletteForegroundColor( KGlobalSettings::highlightedTextColor() );
+      setPaletteBackgroundColor( KGlobalSettings::highlightColor() );
     }
 }
 
@@ -147,4 +153,9 @@ void RSIRelaxPopup::setVisible( bool b )
     if( !b ) hide();
 }
 
+void RSIRelaxPopup::setSkipButtonHidden ( bool b )
+{
+    m_skipbutton->setHidden( b );
+}
+
 #include "rsirelaxpopup.moc"
