@@ -46,6 +46,7 @@ RSITimer::RSITimer( QObject *parent, const char *name )
     , m_bigBreakRequested( false )
     , m_suspended( false )
     , m_needRestart( false )
+    , m_explicitDebug (false )
     , m_pause_left( 0 ), m_relax_left( 0 )
     , dpmsOff( -10 ), dpmsStandby(-10), dpmsSuspend(-10)
     , m_lastActivity( QDateTime::currentDateTime() )
@@ -53,14 +54,6 @@ RSITimer::RSITimer( QObject *parent, const char *name )
 {
     kdDebug() << "Starting timer constructor" << endl;
 
-    // if big_maximized < tiny_maximized, the bigbreaks will not get reset,
-    // guard against that situation.
-    if (m_intervals["big_maximized"] < m_intervals["tiny_maximized"])
-    {
-      kdDebug() << "max big > max tiny, not allowed & corrected" << endl;
-      m_intervals["big_maximized"] = m_intervals["tiny_maximized"];
-    }
-
     startTimer( 1000 );
     slotReadConfig( /* restart */ true );
 
@@ -138,7 +131,7 @@ void RSITimer::resetAfterTinyBreak()
     m_tiny_left = m_intervals["tiny_minimized"];
     resetAfterBreak();
     emit updateToolTip( m_tiny_left, m_big_left );
-    RSIGlobals::instance()->DCOPBreak( false, false );
+    RSIGlobals::instance()->NotifyBreak( false, false );
 
     if ( m_big_left < m_tiny_left )
     {
@@ -153,7 +146,7 @@ void RSITimer::resetAfterBigBreak()
     m_big_left = m_intervals["big_minimized"];
     resetAfterBreak();
     emit updateToolTip( m_tiny_left, m_big_left );
-    RSIGlobals::instance()->DCOPBreak( false, true );
+    RSIGlobals::instance()->NotifyBreak( false, true );
 }
 
 // -------------------------- SLOTS ------------------------//
@@ -230,6 +223,11 @@ void RSITimer::slotRequestBreak()
     m_breakRequested = true;
 }
 
+void RSITimer::slotRequestDebug()
+{
+    m_explicitDebug = true;
+}
+
 void RSITimer::slotRequestTinyBreak()
 {
     slotRequestBreak();
@@ -289,14 +287,14 @@ void RSITimer::timerEvent( QTimerEvent * )
           breakNow( m_intervals["tiny_maximized"] );
           m_pause_left = m_intervals["tiny_maximized"];
           m_nextBreak = TINY_BREAK;
-          RSIGlobals::instance()->DCOPBreak( true, false );
+          RSIGlobals::instance()->NotifyBreak( true, false );
         }
         else if ( m_bigBreakRequested )
         {
           breakNow( m_intervals["big_maximized"] );
           m_pause_left = m_intervals["big_maximized"];
           m_nextBreak = BIG_BREAK;
-          RSIGlobals::instance()->DCOPBreak( true, true );
+          RSIGlobals::instance()->NotifyBreak( true, true );
         }
         else
         {
@@ -333,12 +331,11 @@ void RSITimer::timerEvent( QTimerEvent * )
         return;
     }
 
-    /*
-    kdDebug() << " patience: " << m_patience  << " pause_left: "
+    if (m_explicitDebug)
+        kdDebug() << " patience: " << m_patience  << " pause_left: "
             << m_pause_left << " relax_left: " << m_relax_left
             <<  " tiny_left: " << m_tiny_left  << " big_left: "
             <<  m_big_left << " idle: " << t << endl;
-    */
 
     if ( t == 0 ) // activity!
     {
@@ -352,8 +349,8 @@ void RSITimer::timerEvent( QTimerEvent * )
 
                 breakNow( breakInterval );
                 m_nextBreak == TINY_BREAK  ?
-                        RSIGlobals::instance()->DCOPBreak( true, false ):
-                        RSIGlobals::instance()->DCOPBreak( true, true );
+                        RSIGlobals::instance()->NotifyBreak( true, false ):
+                        RSIGlobals::instance()->NotifyBreak( true, true );
                 m_pause_left = breakInterval;
             }
             else // reset relax dialog
@@ -416,7 +413,7 @@ void RSITimer::timerEvent( QTimerEvent * )
         emit bigBreakSkipped();
     }
     else if ( m_useIdleDetection && t == m_intervals["tiny_maximized"] &&
-              m_tiny_left < m_big_left  )
+              m_tiny_left < m_big_left && !m_ignoreIdleForTinyBreaks )
     {
         // the user was sufficiently idle for a tiny break
         if ( m_relax_left == 0 && m_pause_left == 0 )
@@ -447,7 +444,7 @@ void RSITimer::timerEvent( QTimerEvent * )
 
     // update the stats properly when breaking
     if ( m_useIdleDetection && t > m_intervals["tiny_maximized"] &&
-         m_relax_left == 0 && m_pause_left == 0 )
+         m_relax_left == 0 && m_pause_left == 0 && !m_ignoreIdleForTinyBreaks)
     {
         RSIGlobals::instance()->stats()->setStat( LAST_TINY_BREAK, QVariant( QDateTime::currentDateTime() ) );
     }
@@ -466,7 +463,7 @@ void RSITimer::timerEvent( QTimerEvent * )
             RSIGlobals::instance()->stats()->increaseStat( BIG_BREAKS );
         }
 
-        m_patience = 15;
+        m_patience = 30;
         if (m_patience > breakInterval)
             m_patience=breakInterval;
 
@@ -486,6 +483,7 @@ void RSITimer::readConfig()
     config->setGroup("General Settings");
 
     m_useIdleDetection = config->readBoolEntry("UseIdleDetection", true);
+    m_ignoreIdleForTinyBreaks = config->readBoolEntry("IgnoreIdleForTinyBreaks", false);
 
     config->setGroup("General");
     QDateTime *tempDt = new QDateTime();
@@ -559,14 +557,14 @@ void RSITimerNoIdle::timerEvent( QTimerEvent * )
             breakNow( m_intervals["tiny_maximized"] );
             m_pause_left = m_intervals["tiny_maximized"];
             m_nextBreak = TINY_BREAK;
-            RSIGlobals::instance()->DCOPBreak( true, false );
+            RSIGlobals::instance()->NotifyBreak( true, false );
         }
         else if ( m_bigBreakRequested )
         {
             breakNow( m_intervals["big_maximized"] );
             m_pause_left = m_intervals["big_maximized"];
             m_nextBreak = BIG_BREAK;
-            RSIGlobals::instance()->DCOPBreak( true, true );
+            RSIGlobals::instance()->NotifyBreak( true, true );
         }
 
         breakNow( breakInterval );
@@ -577,12 +575,10 @@ void RSITimerNoIdle::timerEvent( QTimerEvent * )
         m_relax_left = 0;
     }
 
-    /*
-    kdDebug() << " patience: " << m_patience  << " pause_left: "
-    << m_pause_left << " relax_left: " << m_relax_left
-    <<  " tiny_left: " << m_tiny_left  << " big_left: "
-    <<  m_big_left << endl;
-    */
+    if (m_explicitDebug)
+        kdDebug() << " pause_left: " << m_pause_left
+                <<  " tiny_left: " << m_tiny_left  << " big_left: "
+                <<  m_big_left << " m_nextbeak: " << m_nextBreak << endl;
 
     if ( m_pause_left > 0 )
     {
@@ -611,14 +607,14 @@ void RSITimerNoIdle::timerEvent( QTimerEvent * )
         }
     }
 
-    if ( m_pause_left == 0 && m_tiny_left == 0 )
+    if ( m_pause_left == 0 && m_tiny_left == 0 && m_big_left != 0)
     {
         m_pause_left = breakInterval;
         m_nextBreak = TINY_BREAK;
         breakNow( breakInterval );
         RSIGlobals::instance()->stats()->setStat( LAST_TINY_BREAK,
                                 QVariant( QDateTime::currentDateTime() ) );
-        RSIGlobals::instance()->DCOPBreak( true, false );
+        RSIGlobals::instance()->NotifyBreak( true, false );
         RSIGlobals::instance()->stats()->increaseStat( TINY_BREAKS );
     }
     else
@@ -633,7 +629,7 @@ void RSITimerNoIdle::timerEvent( QTimerEvent * )
         breakNow( breakInterval );
         RSIGlobals::instance()->stats()->setStat( LAST_BIG_BREAK,
                                 QVariant( QDateTime::currentDateTime() ) );
-        RSIGlobals::instance()->DCOPBreak( true, true );
+        RSIGlobals::instance()->NotifyBreak( true, true );
         RSIGlobals::instance()->stats()->increaseStat( BIG_BREAKS );
      }
     else
