@@ -43,6 +43,7 @@
 #include <kiconloader.h>
 #include <kpixmap.h>
 #include <kimageeffect.h>
+#include <kglobal.h>
 
 #include <stdlib.h>
 #include <time.h>
@@ -56,10 +57,15 @@
 #include "rsiglobals.h"
 
 RSIWidget::RSIWidget( QWidget *parent, const char *name )
-    : QWidget( parent, name, WType_Popup),
-     m_currentY( 0 )
+    : QWidget( parent, name, WType_Popup)
+    , m_currentY( 0 )
+    , m_useImages( false )
+    , m_searchRecursive( false )
 {
 
+    // Update legacy settings before reading any config.
+    RSIGlobals::updateLegacySettings();
+
     // Keep these 3 lines _above_ the messagebox, so the text actually is right.
     m_tray = new RSIDock(this,"Tray Item");
     m_tray->setPixmap( KSystemTray::loadIcon("rsibreak0") );
@@ -67,52 +73,7 @@ RSIWidget::RSIWidget( QWidget *parent, const char *name )
 
     if (KMessageBox::shouldBeShownContinue("dont_show_welcome_again_for_001"))
     {
-        // Process the events else the icon will not be there and the screenie will fail!
-        kapp->processEvents();
-
-        // ********************************************************************************
-        // This block is copied from Konversation - KonversationMainWindow::queryClose()
-        // The part about the border is copied from  KSystemTray::displayCloseMessage()
-        //
-        // Compute size and position of the pixmap to be grabbed:
-        QPoint g = m_tray->mapToGlobal( m_tray-> pos() );
-        int desktopWidth  = kapp->desktop()->width();
-        int desktopHeight = kapp->desktop()->height();
-        int tw = m_tray->width();
-        int th = m_tray->height();
-        int w = desktopWidth / 4;
-        int h = desktopHeight / 9;
-        int x = g.x() + tw/2 - w/2;               // Center the rectange in the systray icon
-        int y = g.y() + th/2 - h/2;
-        if ( x < 0 )                 x = 0;       // Move the rectangle to stay in the desktop limits
-        if ( y < 0 )                 y = 0;
-        if ( x + w > desktopWidth )  x = desktopWidth - w;
-        if ( y + h > desktopHeight ) y = desktopHeight - h;
-
-        // Grab the desktop and draw a circle arround the icon:
-        QPixmap shot = QPixmap::grabWindow( qt_xrootwin(),  x,  y,  w,  h );
-        QPainter painter( &shot );
-        const int MARGINS = 6;
-        const int WIDTH   = 3;
-        int ax = g.x() - x - MARGINS -1;
-        int ay = g.y() - y - MARGINS -1;
-        painter.setPen(  QPen( Qt::red,  WIDTH ) );
-        painter.drawArc( ax,  ay,  tw + 2*MARGINS,  th + 2*MARGINS,  0,  16*360 );
-        painter.end();
-
-        // Then, we add a border arround the image to make it more visible:
-        QPixmap finalShot(w + 2, h + 2);
-        finalShot.fill(KApplication::palette().active().foreground());
-        painter.begin(&finalShot);
-        painter.drawPixmap(1, 1, shot);
-        painter.end();
-
-        // Associate source to image and show the dialog:
-        QMimeSourceFactory::defaultFactory()->setPixmap( "systray_shot", finalShot );
-
-        // End copied block
-        // ********************************************************************************
-
+        takeScreenshotOfTrayIcon();
         KMessageBox::information(parent,
                              i18n("<p>Welcome to RSIBreak<p><p>"
                                   "In your tray you can now see RSIBreak: ")
@@ -125,7 +86,7 @@ RSIWidget::RSIWidget( QWidget *parent, const char *name )
                              i18n("Welcome"),
                              "dont_show_welcome_again_for_001");
 
-        // we dont need to show the blurp about the changes in 0.5 for new users.
+        // we don't need to show the blurp about the changes in 0.5 for new users.
         KMessageBox::saveDontShowAgainContinue("dont_show_welcome_again_for_050");
     }
     else
@@ -136,7 +97,7 @@ RSIWidget::RSIWidget( QWidget *parent, const char *name )
                                       "the number of short breaks you want to "
                                       "take before taking a long break, you "
                                       "can now setup how often, in minutes, "
-                                      "you want a lomg break.\nPlease review "
+                                      "you want a long break.\nPlease review "
                                       "your current settings.\n\n"),
                                  i18n("Welcome"),
                                  "dont_show_welcome_again_for_050");
@@ -144,8 +105,9 @@ RSIWidget::RSIWidget( QWidget *parent, const char *name )
     m_backgroundimage.resize(QApplication::desktop()->width(),
                              QApplication::desktop()->height());
     setBackgroundMode( QWidget::NoBackground );
-    setGeometry( QApplication::desktop()->screenGeometry( this ) );
-    move(0,0);
+    QRect rect = QApplication::desktop()->screenGeometry(
+                        QApplication::desktop()->primaryScreen() );
+    setGeometry( rect );
 
     m_tooltip = new RSIToolTip( m_tray, "Tooltip" );
     connect( m_tray, SIGNAL( showToolTip() ), m_tooltip, SLOT( show() ) );
@@ -166,13 +128,15 @@ RSIWidget::RSIWidget( QWidget *parent, const char *name )
              m_tooltip, SLOT( setSuspended( bool ) ) );
     connect( m_dcopIface, SIGNAL( signalSuspend( bool) ),
              m_relaxpopup, SLOT( setVisible( bool ) ) );
+    connect( m_dcopIface, SIGNAL( signalWhereAmI() ),
+             this, SLOT( slotShowWhereIAm() ) );
 
     srand ( time(NULL) );
 
     QBoxLayout *topLayout = new QVBoxLayout( this, 5);
 
     m_countDown = new RSILabel(this);
-    m_countDown->setAlignment( AlignCenter );
+    m_countDown->setAlignment( AlignRight );
     m_countDown->setBackgroundMode( Qt::NoBackground );
     m_countDown->setBackgroundOrigin(QWidget::ParentOrigin);
     m_countDown->hide();
@@ -216,6 +180,64 @@ RSIWidget::~RSIWidget()
     delete RSIGlobals::instance();
 }
 
+void RSIWidget::slotShowWhereIAm()
+{
+    takeScreenshotOfTrayIcon();
+    KMessageBox::information(this,
+           i18n("<p>RSIBreak is already running<p><p>It is located here:")
+           + "<p><center><img source=\"systray_shot\"></center></p><p>",
+           i18n("Already Running"));
+}
+
+void RSIWidget::takeScreenshotOfTrayIcon()
+{
+        // Process the events else the icon will not be there and the screenie will fail!
+        kapp->processEvents();
+
+        // ********************************************************************************
+        // This block is copied from Konversation - KonversationMainWindow::queryClose()
+        // The part about the border is copied from  KSystemTray::displayCloseMessage()
+        //
+        // Compute size and position of the pixmap to be grabbed:
+        QPoint g = m_tray->mapToGlobal( m_tray-> pos() );
+        int desktopWidth  = kapp->desktop()->width();
+        int desktopHeight = kapp->desktop()->height();
+        int tw = m_tray->width();
+        int th = m_tray->height();
+        int w = desktopWidth / 4;
+        int h = desktopHeight / 9;
+        int x = g.x() + tw/2 - w/2;               // Center the rectange in the systray icon
+        int y = g.y() + th/2 - h/2;
+        if ( x < 0 )                 x = 0;       // Move the rectangle to stay in the desktop limits
+        if ( y < 0 )                 y = 0;
+        if ( x + w > desktopWidth )  x = desktopWidth - w;
+        if ( y + h > desktopHeight ) y = desktopHeight - h;
+
+        // Grab the desktop and draw a circle around the icon:
+        QPixmap shot = QPixmap::grabWindow( qt_xrootwin(),  x,  y,  w,  h );
+        QPainter painter( &shot );
+        const int MARGINS = 6;
+        const int WIDTH   = 3;
+        int ax = g.x() - x - MARGINS -1;
+        int ay = g.y() - y - MARGINS -1;
+        painter.setPen(  QPen( Qt::red,  WIDTH ) );
+        painter.drawArc( ax,  ay,  tw + 2*MARGINS,  th + 2*MARGINS,  0,  16*360 );
+        painter.end();
+
+        // Then, we add a border around the image to make it more visible:
+        QPixmap finalShot(w + 2, h + 2);
+        finalShot.fill(KApplication::palette().active().foreground());
+        painter.begin(&finalShot);
+        painter.drawPixmap(1, 1, shot);
+        painter.end();
+
+        // Associate source to image and show the dialog:
+        QMimeSourceFactory::defaultFactory()->setPixmap( "systray_shot", finalShot );
+
+        // End copied block
+        // ********************************************************************************
+}
+
 void RSIWidget::minimize( bool newImage )
 {
     // stop the m_grab, if the break is ESCaped during the
@@ -253,11 +275,17 @@ void RSIWidget::maximize()
     m_countDown->hide();
     if (m_files.count() == 0 || !m_useImages)
     {
+        m_backgroundimage.resize(QApplication::desktop()->geometry().width(),
+                             QApplication::desktop()->geometry().height());
+        setGeometry( QApplication::desktop()->geometry() );
         m_currentY=0;
         QTimer::singleShot( 10, this, SLOT( slotGrayEffect() ) );
     }
     else
     {
+        m_backgroundimage.resize(QApplication::desktop()->width(),
+                             QApplication::desktop()->height());
+        setGeometry( QApplication::desktop()->screenGeometry( this ) );
         if (m_slideInterval>0)
             m_timer_slide->start( m_slideInterval*1000 );
 
@@ -270,28 +298,56 @@ void RSIWidget::loadImage()
     if (m_files.count() == 0)
         return;
 
-    // reset if all images are shown
-    if (m_files_done.count() == m_files.count())
-        m_files_done.clear();
-
-    // get a not yet used number
-    int j = (int) ((m_files.count()) * (rand() / (RAND_MAX + 1.0)));
-    while (m_files_done.findIndex( QString::number(j) ) != -1)
-        j = (int) ((m_files.count()) * (rand() / (RAND_MAX + 1.0)));
-
-    // Use that number to load the right image
-    m_files_done.append(QString::number(j));
-
-    kdDebug() << "Loading: " << m_files[j] <<
-                    "( " << j << " / "  << m_files.count() << " ) " << endl;
-
     // Base the size on the size of the screen, for xinerama.
     QRect size = QApplication::desktop()->screenGeometry(
                         QApplication::desktop()->primaryScreen() );
 
-    QImage m = QImage( m_files[ j ]).smoothScale( size.width(),
-                                                  size.height(),
-                                                  QImage::ScaleMax);
+    // Do not accept images whose surface is more than 3 times smaller than
+    // screen
+    int min_image_surface = size.width() * size.height() / 3;
+    QImage image;
+
+    while (true)
+    {
+        // reset if all images are shown
+        if (m_files_done.count() == m_files.count())
+            m_files_done.clear();
+
+        // get a not yet used image
+        int j;
+        QString name;
+        do
+        {
+            j = (int) (m_files.count() * (rand() / (RAND_MAX + 1.0)));
+            name = m_files[ j ];
+        } while (m_files_done.findIndex( name ) != -1);
+
+        // load image
+        kdDebug() << "Loading: " << name <<
+                        "( " << j << " / "  << m_files.count() << " ) " << endl;
+        image.load( name );
+
+        // Check size
+        if ( image.width() * image.height() >= min_image_surface ) {
+            // Image is big enough, leave while loop
+            m_files_done.append( name );
+            break;
+        }
+        else
+        {
+            // Too small, remove from list
+            m_files.remove( name );
+            if (m_files.count() == 0)
+            {
+                // Couldn't find any image big enough, leave function
+                return;
+            }
+        }
+    }
+
+    QImage m = image.smoothScale( size.width(),
+                                  size.height(),
+                                  QImage::ScaleMax);
 
     if (m.isNull())
         return;
@@ -455,14 +511,13 @@ void RSIWidget::updateIdleAvg( double idleAvg )
 void RSIWidget::setIcon(int level)
 {
     static QString currentIcon;
-    static KIconLoader il;
     QString newIcon = "rsibreak" +
                       ( m_timer->isSuspended() ? QString("x") : QString::number(level) );
 
     if (newIcon != currentIcon)
     {
         QPixmap dockPixmap = KSystemTray::loadIcon( newIcon );
-        QPixmap toolPixmap = il.loadIcon( newIcon, KIcon::Desktop );
+        QPixmap toolPixmap = KGlobal::iconLoader()->loadIcon( newIcon, KIcon::Desktop );
         currentIcon = newIcon;
         m_tray->setPixmap( dockPixmap );
         m_tooltip->setPixmap( toolPixmap );
@@ -491,12 +546,10 @@ void RSIWidget::bigBreakSkipped()
 
 void RSIWidget::breakSkipped()
 {
-    static KIconLoader il;
-
     disconnect( m_timer, SIGNAL( updateToolTip( int, int ) ),
                 m_tooltip, SLOT( setCounters( int, int ) ) );
 
-    m_tooltip->setPixmap( il.loadIcon( "rsibreak0", KIcon::Desktop ) );
+    m_tooltip->setPixmap( KGlobal::iconLoader()->loadIcon( "rsibreak0", KIcon::Desktop ) );
     m_tooltip->setTimeout(0); // autoDelete is false, but after the ->show() it still
                               // gets hidden after the timeout. Setting to 0 helps.
     m_tooltip->show();
@@ -598,6 +651,7 @@ void RSIWidget::startTimer( bool idle)
     connect( m_tray, SIGNAL( dialogEntered() ), m_timer, SLOT( slotStopNoImage( ) ) );
     connect( m_tray, SIGNAL( dialogLeft() ), m_timer, SLOT( slotStartNoImage() ) );
     connect( m_tray, SIGNAL( breakRequest() ), m_timer, SLOT( slotRequestBreak() ) );
+    connect( m_tray, SIGNAL( debugRequest() ), m_timer, SLOT( slotRequestDebug() ) );
     connect( m_tray, SIGNAL( suspend( bool ) ), m_timer, SLOT( slotSuspended( bool ) ) );
 
     connect( m_dcopIface, SIGNAL( signalDoTinyBreak() ),
@@ -607,6 +661,8 @@ void RSIWidget::startTimer( bool idle)
     connect( m_dcopIface, SIGNAL( signalSuspend( bool) ),
              m_timer, SLOT( slotSuspended( bool ) ) );
 
+    connect( m_relaxpopup, SIGNAL( skip() ), m_timer, SLOT( skipBreak() ) );
+
     // This connects only get used when there the user locks and
     // unlocks before the break is over. The lock releases the mouse
     // and keyboard, and that way the event methods are not called.
@@ -630,13 +686,15 @@ void RSIWidget::readConfig()
             config->readColorEntry("CounterColor", Black ) );
     m_miniButton->setHidden(
             config->readBoolEntry("HideMinimizeButton", false));
+    m_relaxpopup->setSkipButtonHidden(
+            config->readBoolEntry("HideMinimizeButton", false));
     m_countDown->setHidden(
             config->readBoolEntry("HideCounter", false));
 
     m_countDown->setFont(
             config->readFontEntry("CounterFont", t ) );
 
-    bool uImages = config->readBoolEntry("ShowImages", false);
+    bool useImages = config->readBoolEntry("ShowImages", false);
 
     bool recursive =
             config->readBoolEntry("SearchRecursiveCheck", false);
@@ -652,13 +710,13 @@ void RSIWidget::readConfig()
     m_accel->setShortcut("minimize",KShortcut(shortcut));
 
     if (m_basePath != path || m_searchRecursive != recursive ||
-        m_useImages != uImages )
+        m_useImages != useImages )
     {
         m_files.clear();
         m_files_done.clear();
         m_basePath = path;
         m_searchRecursive = recursive;
-        m_useImages = uImages;
+        m_useImages = useImages;
         if (m_useImages)
         {
             findImagesInFolder( path );
@@ -668,7 +726,11 @@ void RSIWidget::readConfig()
         }
     }
 
-    m_slideInterval = config->readNumEntry("SlideInterval", 2);
+//  Ok. So I have no idea. Without setting the group _again_ we do not get a valid 
+//  result. Again, by re-setting it I get the value from the config file, and without it not.
+    config->setGroup("General Settings");
+    
+    m_slideInterval = config->readNumEntry("SlideInterval", 10);
     m_showTimerReset = config->readBoolEntry("ShowTimerReset", false);
 
     delete Black;
