@@ -86,6 +86,7 @@ class RSIWidget : public QWidget
         ~RSIWidget();
 
     private slots:
+        void slotShowWhereIAm();
         void slotNewSlide();
         void slotLock();
         void minimize( bool newImage = true );
@@ -106,10 +107,11 @@ class RSIWidget : public QWidget
         virtual void mouseReleaseEvent( QMouseEvent * e );
         virtual void keyPressEvent( QKeyEvent * e);
 
-        /** Sets appropiate icon in tooltip and docker. */
+        /** Sets appropriate icon in tooltip and docker. */
         void setIcon( int );
 
     private:
+        void takeScreenshotOfTrayIcon();
         void findImagesInFolder(const QString& folder);
         void loadImage();
         void startTimer( bool idle);
@@ -144,4 +146,4 @@ class RSIWidget : public QWidget
         bool            m_useIdleDetection;
 };
 
-#endif
+#   endif
