@@ -177,14 +177,14 @@ void SetupTiming::readSettings()
     KConfig* config = kapp->config();
 
     config->setGroup("General Settings");
+    d->debug = config->readBoolEntry("DEBUG", false);
+
     d->tinyInterval->setValue(config->readNumEntry("TinyInterval", 10));
     d->tinyDuration->setValue(config->readNumEntry("TinyDuration", 20));
     d->bigInterval->setValue(config->readNumEntry("BigInterval", 60));
     d->bigInterval->setMinValue( d->tinyInterval->value() );
     d->bigDuration->setValue(config->readNumEntry("BigDuration", 1));
-    d->slideInterval->setValue(config->readNumEntry("SlideInterval", 2));
-
-    d->debug = config->readBoolEntry("DEBUG");
+    d->slideInterval->setValue(config->readNumEntry("SlideInterval", 10));
 }
 
 void SetupTiming::slotTinyValueChanged( int i )
